@@ -36,6 +36,7 @@ const char *Checks::chkRecall(Line *line, ScriptImage *img)
 	return NULL;
 }
 
+
 const char *Checks::chkReconnect(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
@@ -48,6 +49,27 @@ const char *Checks::chkReconnect(Line *line, ScriptImage *img)
 	return NULL;
 }
 
+const char *Checks::chkFeature(Line *line, ScriptImage *img)
+{
+        if(!useKeywords(line, "=encoding=framing"))
+                return "invalid keyword used for reconnect";
+
+        return NULL;
+}
+
+const char *Checks::chkRing(Line *line, ScriptImage *img)
+{
+	unsigned idx = 0;
+
+	if(!useKeywords(line, "=coverage=delay=timeout=duration=tone=encoding=framing"))
+		return "invalud keyword used for ring";
+
+	if(!getOption(line, &idx))
+		return "select at least one ring group script to use";
+
+	return NULL;
+}
+
 const char *Checks::chkConnect(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
