@@ -37,7 +37,9 @@ timeout_t Bayonne::reset_timer = 60;
 timeout_t Bayonne::exec_timer = 60000;
 Bayonne::Traffic Bayonne::total_call_attempts;
 Bayonne::Traffic Bayonne::total_call_complete;
+Mutex Bayonne::Ring::locker;
 Mutex Bayonne::serialize;
+Bayonne::Ring *Bayonne::Ring::free = NULL;
 ThreadLock Bayonne::reloading;
 char Bayonne::sla[64] = {0};
 unsigned Bayonne::idle_count = 0;
@@ -81,6 +83,7 @@ Bayonne::statetab Bayonne::states[] = {
 	{"record", &BayonneSession::stateRecord, 'r'},
 	{"join", &BayonneSession::stateJoin, 'j'},
 	{"accept", &BayonneSession::stateWait, 'w'},
+	{"calling", &BayonneSession::stateCalling, 'd'},
 	{"connect", &BayonneSession::stateConnect, 'd'},
 	{"reconnect", &BayonneSession::stateReconnect, '#'},
 	{"hunting", &BayonneSession::stateHunting, 'o'},
@@ -94,6 +97,109 @@ Bayonne::statetab Bayonne::states[] = {
 	{"final", &BayonneSession::stateFinal, ' '},
 	{NULL, NULL, ' '}};
 
+Bayonne::Ring *Bayonne::Ring::find(Ring *r, BayonneSession *s)
+{
+	while(r)
+	{
+		if(r->session == s)
+			return r;
+		r = r->next;
+	}
+	return NULL;
+}
+
+void Bayonne::Ring::start(Ring *r, BayonneSession *sp)
+{
+	Event event;
+	const char *cp;
+
+	while(r)
+	{
+		if(!r->driver || r->session != NULL || !r->script)
+			goto next;
+
+		cp = r->driver->getLast("type");
+		if(cp && !stricmp(cp, "proto"))
+			r->session = r->driver->getIdle();
+		else
+			r->session = getSession(r->driver->getFirst() + atoi(r->ring_id));
+
+		if(!r->session)
+			goto next;
+
+		if(r->count)
+		{
+			--r->count;
+			goto next;
+		}
+
+		memset(&event, 0, sizeof(event));
+		event.id = START_RINGING;
+		event.start.img = sp->getImage();
+		event.start.scr = r->script;
+		event.start.dialing = r->ring_id;
+		event.start.parent = sp;
+		r->session->postEvent(&event);	
+next:
+		r = r->next;
+	}
+}
+
+void Bayonne::Ring::detach(Ring *r)
+{
+	Event event;
+	Ring *n;
+	while(r)
+	{
+		if(r->session)
+		{
+			memset(&event, 0, sizeof(event));
+			event.id = CANCEL_CHILD;
+			r->session->queEvent(&event);
+		}
+		n = r->next;
+		locker.enter();
+		r->next = free;
+		free = r;
+		locker.leave();
+		r = n;
+	}
+}
+
+Bayonne::Ring *Bayonne::Ring::attach(BayonneDriver *d, const char *id, Ring *list)
+{
+	Ring *r;
+	locker.enter();
+	r = list;
+
+	// make sure we only attach new and unique entries...
+
+	while(r)
+	{
+		if(d == r->driver && !stricmp(id, r->ring_id))
+		{
+			locker.leave();
+			return NULL;
+		}
+		r = r->next;
+	}
+	if(free)
+	{
+		r = free;
+		free = r->next;
+	}
+	else
+		r = new Ring();
+	locker.leave();
+	r->next = list;
+	r->ring_id = id;
+	r->driver = d;
+	r->session = NULL;
+	r->script = NULL;
+	r->count = 0;
+	return r;
+};
+
 Bayonne::Call::Call(BayonneSession *dest, const char *from)
 {
 	time_t buf;
@@ -105,8 +211,9 @@ Bayonne::Call::Call(BayonneSession *dest, const char *from)
 	setString(call_from, sizeof(call_from), from);
 	setString(call_to, sizeof(call_to), dn);
 	call_connect = 0;
+	call_encoding = dest->audioEncoding();
 	refcount = 1;
-	type = dest->type;
+	call_type = dest->type;
 	call_start = time(&buf);
 }
 
