@@ -200,6 +200,7 @@ public:
 		STATE_RECORD,
 		STATE_JOIN,
 		STATE_WAIT,
+		STATE_CALLING,
 		STATE_CONNECT,
 		STATE_RECONNECT,
 		STATE_HUNTING,
@@ -295,6 +296,7 @@ public:
 		EXIT_HUNTING,
 		ENTER_RECONNECT,
 		EXIT_RECONNECT,
+		RECALL_RECONNECT,
 
 		// primary session control events
 
@@ -366,6 +368,7 @@ public:
 		DEVICE_OPEN,
 		DEVICE_CLOSE,
 		DSP_READY,
+		RING_SYNC,
 
 		// primary call processing events
 
@@ -607,15 +610,40 @@ public:
 			const char *errmsg;
 			BayonneSession *pid;
 			BayonneSession *peer;
+			BayonneSession *child;
 			void *data;
 		};
 
 	}	Event;
 
+	/**
+	 * This is an internal ring class for synchronized ringing.
+	 */
+	class __EXPORT Ring
+	{
+	private:
+		static Mutex locker;
+		static Ring *free;
+		Ring *next;
+
+		Ring() {};
+	public:
+		BayonneDriver *driver;
+		const char *ring_id;
+		unsigned count;
+		BayonneSession *session;
+		Script::Name *script;
+
+		static Ring *attach(BayonneDriver *d, const char *id, Ring *list);
+		static void detach(Ring *list);
+		static Ring *find(Ring *list, BayonneSession *s);
+		static void start(Ring *list, BayonneSession *s);
+	};
+
 	/**
  	 * This is an internal call class.
 	 */
-	class __EXPORT Call
+	class __EXPORT Call : public Audio
 	{
 	private:
 		volatile unsigned refcount;
@@ -624,7 +652,8 @@ public:
 		volatile time_t call_start, call_connect;
 		char call_from[65], call_to[65], call_reason[16];
 		char call_code[16], call_id[16];
-		calltype_t type;
+		calltype_t call_type;
+		const char *call_encoding;
 
 		Call(BayonneSession *target, const char *from);
 		void detach(const char *reason = NULL);
@@ -2048,6 +2077,7 @@ protected:
 
 	std::ostream *logevents, *logtrace;
 	Call *call;
+	Ring *ring;
 	BayonneDriver *driver;
 	BayonneMsgport *msgport;
 	BayonneSession *peer;
@@ -2176,6 +2206,7 @@ protected:
 	bool stateWait(Event *event);
 	bool stateConnect(Event *event);
 	bool stateReconnect(Event *event);
+	bool stateCalling(Event *event);
 
 	/**
 	 * Set call reference pointer.  If previous call is set, then
@@ -2315,6 +2346,12 @@ protected:
 	 */
 	bool setReconnect(const char *enc, timeout_t framing);
 
+
+	/**
+	 * Attempt to readjust encoding of active session for recall.
+	 */
+	bool recallReconnect(void);
+
 	/**
 	 * Set the session to the connecting (join) state or run state
 	 * based on flags and circumstances from seize/pickup.
