@@ -51,6 +51,7 @@ ScriptInterp(), audio()
 	peer = NULL;
 	connecting = false;
 	call = NULL;
+	ring = NULL;
 
 	if(!translator)
 		translator = &langNone;
@@ -1003,6 +1004,19 @@ void BayonneSession::setConnecting(const char *evname)
 	setRunning();
 }
 
+bool BayonneSession::recallReconnect(void)
+{
+	Event ev;
+
+	memset(&ev, 0, sizeof(ev));
+	ev.id = RECALL_RECONNECT;
+	if(!enterReconnect(&ev))
+		return false;
+
+	setState(STATE_RECONNECT);
+	return true;
+}
+
 bool BayonneSession::setReconnect(const char *enc, timeout_t framing)
 {
 	Event ev;
@@ -1387,6 +1401,12 @@ void BayonneSession::makeIdle(void)
 
 	setCall(NULL);
 
+	if(ring)
+	{
+		Ring::detach(ring);
+		ring = NULL;
+	}
+
 	if(thread)
         {
         	delete thread;
