@@ -358,6 +358,7 @@ bool BayonneSession::stateStart(Event *event)
 	case CHILD_FAX:
 		if(!scriptEvent("start:fax"))
 			error("start-fax");
+		setRunning();
 		return true;
 	case CHILD_RUNNING:
 		advance();
@@ -910,6 +911,7 @@ bool BayonneSession::stateReconnect(Event *event)
 	switch(event->id)
 	{
 	case ENTER_RECONNECT:
+	case RECALL_RECONNECT:
 		return false;
 	case ENTER_STATE:
 		if(state.timeout && state.timeout != TIMEOUT_INF)
@@ -931,6 +933,88 @@ finish:
 	}
 }
 
+bool BayonneSession::stateCalling(Event *event)
+{
+	bool dtmf, refer, hangup;
+	Ring *r;
+
+	if(event->id == TIMER_EXPIRED)
+	{
+		if(state.timeout)
+			event->id = RING_SYNC;
+	}
+
+	if(enterTone(event))
+		return true;
+
+	switch(event->id)
+	{
+	case TIMER_EXPIRED:
+		Ring::detach(ring);
+		ring = NULL;
+		if(!scriptEvent("call:expired"))
+			error("call-expired");
+		setRunning();
+		return true;
+	case CHILD_DND:
+	case CHILD_AWAY:
+	case CHILD_NOCODEC:
+	case CHILD_INVALID:
+	case CHILD_OFFLINE:
+		r =Ring::find(ring, event->child);
+		if(!r)
+			return false;
+		r->session = NULL;
+		r->driver = NULL;
+		return true;
+	case CHILD_BUSY:
+	case CHILD_FAILED:
+		r = Ring::find(ring, event->child);
+		if(!r)		
+			return false;
+		r->session = NULL;
+		return true;
+	case CHILD_FAX:
+		r = Ring::find(ring, event->child);
+		r->session = NULL;
+		if(!scriptEvent("call:fax"))
+			error("call-fax");
+		setRunning();
+		return true;
+	case PEER_WAITING:
+		r = Ring::find(ring, event->peer);
+		if(!r)
+			return false;
+		r->session = NULL;
+		dtmf = state.tone.dtmf;
+		hangup = state.tone.hangup;
+		refer = state.tone.refer;
+		state.timeout = state.tone.duration;
+		state.join.dtmf = dtmf;
+		state.join.hangup = hangup;
+		state.join.refer = refer;
+		state.join.dial = NULL;
+		state.join.exit = NULL;
+		state.join.peer = event->peer;
+		Ring::detach(ring);
+		clrAudio();
+		setState(STATE_JOIN);
+		return true;
+	case RING_SYNC:
+	case ENTER_STATE:
+		Ring::start(ring, this);
+		if(state.timeout < 4000)
+			state.timeout = 0;
+		else
+			state.timeout -= 4000;
+		startTimer(4000);
+		return true;
+	default:
+		return enterCommon(event);
+	}
+}
+
+
 bool BayonneSession::stateConnect(Event *event)
 {
 	Event cancel;
@@ -1441,6 +1525,7 @@ bool BayonneSession::stateWait(Event *event)
 			return true;
 		memset(&pe, 0, sizeof(pe));
 		pe.id = PEER_WAITING;
+		pe.peer = this;
 		state.join.peer->queEvent(&pe);
 		return true;
 	case JOIN_PEER:
@@ -2124,10 +2209,16 @@ bool BayonneSession::stateRunning(Event *event)
 	switch(event->id)
 	{
 	case ENTER_STATE:
+		if(ring)
+		{
+			Ring::detach(ring);
+			ring = NULL;
+		}
 		check();
 		if(!starting)
 		{
 			event->id = seizure;
+			event->child = this;
 			parent = getSid(var_pid);
 			if(parent)
 				parent->queEvent(event);
@@ -2254,6 +2345,12 @@ bool BayonneSession::stateHangup(Event *event)
 		exiting = true;	// definately exiting...
 		newTid();
 
+		if(ring)
+		{
+			Ring::detach(ring);
+			ring = NULL;
+		}
+
 		if(!starting)
 			parent = getSid(var_pid);
 
@@ -2262,6 +2359,7 @@ bool BayonneSession::stateHangup(Event *event)
 		{
 			memset(&pe, 0, sizeof(pe));
 			pe.id = seizure;
+			pe.child = this;
 			parent->queEvent(&pe);
 		}			
 
