@@ -42,7 +42,6 @@ void BayonneTSession::sysPost(const char *sid, char *id, const char *value)
         Event event;
 
         char buf[128];
-        const char *cp;
         char *up;
 
         enter();
@@ -272,7 +271,7 @@ void BayonneTSession::sysPrompt(const char *tsid, const char *voice, const char
 		memset(&state.audio, 0, sizeof(state.audio));
 		if(getAudio())
 		{
-			slog.error("%s: %s", logname, cp);
+			slog.error("%s: %s", logname, "format invalid");
 			state.result = RESULT_INVALID;
 			event.id = RESTART_LIBEXEC;
 			goto post;
@@ -401,7 +400,6 @@ void BayonneTSession::sysSTone(const char *tsid, char *tok)
 	const char *cp;
 	timeout_t timeout = TIMEOUT_INF;
 	Audio::Level level = 26000;
-	TelTone::tonekey_t *key;
 
 	memset(&event, 0, sizeof(event));
 	event.id = TONE_LIBEXEC;
@@ -432,8 +430,6 @@ void BayonneTSession::sysSTone(const char *tsid, char *tok)
 		audio.tone = new AudioTone(f1, level, getToneFraming());
 		state.timeout = timeout;
 		state.tone.exiting = false;
-		
-post:
 		postEvent(&event);
 	}
 	leave();
@@ -446,7 +442,6 @@ void BayonneTSession::sysDTone(const char *tsid, char *tok)
 	const char *cp;
 	timeout_t timeout = TIMEOUT_INF;
 	Audio::Level level = 26000;
-	TelTone::tonekey_t *key;
 
 	memset(&event, 0, sizeof(event));
 	event.id = TONE_LIBEXEC;
@@ -480,8 +475,6 @@ void BayonneTSession::sysDTone(const char *tsid, char *tok)
 		audio.tone = new AudioTone(f1, f2, level, level, getToneFraming());
 		state.timeout = timeout;
 		state.tone.exiting = false;
-		
-post:
 		postEvent(&event);
 	}
 	leave();
@@ -755,7 +748,8 @@ void BayonneTSession::sysHeader(const char *tsid)
 		libWrite(buf);
 		snprintf(buf, sizeof(buf), "SESSION: %s\n", var_sid);
 		libWrite(buf);
-		snprintf(buf, sizeof(buf), "TIMEOUT: %d\n", getLibexecTimeout() / 1000);
+		snprintf(buf, sizeof(buf), "TIMEOUT: %ld\n", 
+			(long)getLibexecTimeout() / 1000);
 		libWrite(buf);
 		if(*dtmf_digits)
 		{
@@ -792,7 +786,8 @@ void BayonneTSession::sysHeader(const char *tsid)
 		snprintf(buf, sizeof(buf), "ENCODING: %s\n",
 			Audio::getName(audio.encoding));
 		libWrite(buf);
-		snprintf(buf, sizeof(buf), "FRAMING: %d\n", audio.framing);
+		snprintf(buf, sizeof(buf), "FRAMING: %ld\n", 
+			(long)audio.framing);
 		libWrite(buf);
 		cp = getKeyword("prefix");
 		if(cp)
