@@ -46,7 +46,7 @@ static Keydata::Define driver[] = {
 	{"invite", "60000"},
 	{"pickup", "2000"},
 	{"hangup", "250"},
-	{"accept", "600"},
+	{"accept", "0"},
 	{"audio", "60"},
 	{"jitter", "2"},
 	{"filler", "false"},
@@ -1348,12 +1348,12 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(ext || gw)
 	{
 		if(!ScriptChecks::useKeywords(line, 
-			"=reconnect=peering=secret=encoding=framing=dtmf=user=count=device=info=answer"))
+			"=reconnect=peering=secret=encoding=framing=dtmf=user=count=device=info=answer=accept"))
 				return "invalid keywords used for sip external";
 	}
 	else if(!ScriptChecks::useKeywords(line, 
 		"=uri=timeout=server=proxy=userid=secret=type=realm=dtmf=reconnect"
-		"=limit=public=encoding=framing=local=caller=service=peering=answer=gateways"))
+		"=limit=public=encoding=framing=local=caller=service=peering=answer=gateways=accept"))
 			return "invalid keywords for sip registry";
 
 	reg->protocol = "sip";
@@ -1372,6 +1372,10 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	reg->reconnect = ScriptChecks::findKeyword(line, "reconnect");
 	reg->answer = ScriptChecks::findKeyword(line, "answer");
 	gateways = ScriptChecks::findKeyword(line, "gateways");
+	
+	cp = ScriptChecks::findKeyword(line, "accept");
+	if(cp)
+		reg->accept = atol(cp);
 
 	if(ext || gw)
 		reg->localid = ScriptChecks::findKeyword(line, "user");
@@ -1465,6 +1469,9 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 			if(cp)
 				reg->framing = atol(cp);
 		}
+		cp = cfg->getLast("accept");
+		if(cp && !reg->accept)
+			reg->accept = atoi(cp);
 		cp = cfg->getLast("answer");
 		if(cp && !reg->answer)
 			reg->answer = cp;
