@@ -130,7 +130,7 @@ public:
 	const char *answer;
 	const char *reconnect;
 	const char *caller;
-	timeout_t framing;
+	timeout_t framing, accept;
 	int regid;
 	unsigned short call_limit;
 
@@ -306,6 +306,8 @@ protected:
 	Info info_saved;
 	bool dtmf_sipinfo;
 	bool reinvite, reconnecting, noinvite;
+	const char *encoding_recall;
+	timeout_t framing_recall;
 	volatile bool dtmf_inband;
 	volatile time_t session_timer;
 
