@@ -419,7 +419,7 @@ void RTPStream::runActive(void)
         for(;;)
         {
 		if(jsend && Driver::sip.send_immediate)
-			jsend = 0;
+			jsend = 0;			
 
 		if(!session->rtp_flag)
 		{
@@ -534,7 +534,7 @@ void RTPStream::runActive(void)
 			}
 			
 		}
-                else if(source)
+                else if(source && !session->holding)
                 {
                         n = source->getBuffer(buffer, size);
 			if(n == size)
