@@ -41,6 +41,7 @@ TimerPort()
 
 	rtp_flag = update_pos = reconnecting = noinvite = false;
 
+	encoding_recall = NULL;
 	peer_buffer = NULL;
 	peer_codec = NULL;
 	session_timer = 0;
@@ -107,6 +108,35 @@ const char *Session::sdpNames(void)
 	}
 }
 
+const char *Session::audioEncoding(void)
+{
+	switch(info.encoding)
+	{
+	case Audio::gsmVoice:
+		return "gsm";
+	case Audio::mulawAudio:
+		return "pcmu";
+	case Audio::alawAudio:
+		return "pcma";
+	case Audio::pcm16Mono:
+		return "linear";
+	case Audio::pcm16Stereo:
+		return "stereo";
+	case Audio::g721ADPCM:
+		return "adpcm";
+	case Audio::g723_2bit:
+		return "a16";
+	case Audio::g723_3bit:
+		return "a24";
+	case Audio::g723_5bit:
+		return "a40";
+	case Audio::g729Audio:
+		return "g729";
+	default:
+		return "unknown";
+	}
+}
+
 const char *Session::sdpEncoding(void)
 {
 	switch(info.encoding)
@@ -191,6 +221,7 @@ void Session::redirect(const char *target, const char *encoding, unsigned char d
 	char addr[65];
 	char *ep;
 	unsigned port;
+	const char *invite = "";
 
 	setString(addr, sizeof(addr), target);
 	ep = strrchr(addr, ':');
@@ -219,9 +250,9 @@ void Session::redirect(const char *target, const char *encoding, unsigned char d
 			"t=0 0\r\n"
 			"m=audio %d RTP/AVP %d %d\r\n"
 			"a=rtpmap:%d %s\r\n"
-			"a=rtpmap:%d telephone-events/8000\r\n",
+			"a=rtpmap:%d telephone-events/8000\r\n%s",
 			++sv, addr, addr, port, data, dtmf,
-			data, encoding, dtmf);
+			data, encoding, dtmf, invite);
 	else
 		snprintf(sdp, sizeof(sdp),
 			"v=0\r\n"
@@ -230,8 +261,8 @@ void Session::redirect(const char *target, const char *encoding, unsigned char d
 			"c=IN IP4 %s\r\n"
 			"t=0 0\r\n"
 			"m=audio %d RTP/AVP %d\r\n"
-			"a=rtpmap:%d %s\r\n",
-			++sv, addr, addr, port, data, data, encoding);
+			"a=rtpmap:%d %s\r\n%s",
+			++sv, addr, addr, port, data, data, encoding, invite);
 	
 	osip_message_set_body(msg, sdp, strlen(sdp));
 	osip_message_set_content_type(msg, "application/sdp");
@@ -485,6 +516,8 @@ void Session::makeIdle(void)
 	noinvite = false;
 	sv = 0;
 
+	encoding_recall = NULL;
+
 	if(offhook)
 		sipRelease();
 	BayonneSession::makeIdle();
@@ -518,6 +551,12 @@ bool Session::enterJoin(Event *event)
 
 	switch(event->id)
 	{
+	case CALL_HOLD:
+		if(!holding)
+			return false;
+		encoding_recall = audioEncoding();
+		framing_recall = info.framing;
+		return false;
 	case EXIT_PARTING:
 		if(reinvite && !isDisconnecting())
 			reconnect();
@@ -1127,6 +1166,11 @@ bool Session::enterPlay(Event *event)
 
 bool Session::enterPickup(Event *event)
 {
+	timeout_t accept;
+	const char *cp;
+	Registry *reg;
+	ScriptImage *img = getImage();
+
 	if(event->id == ENTER_STATE)
 	{
 		offhook = true;
@@ -1136,7 +1180,23 @@ bool Session::enterPickup(Event *event)
 	}
 	else if(event->id == CALL_ACCEPTED)
 	{
-		startTimer(Driver::sip.accept_timer);
+		cp = getSymbol("session.registry");
+		if(cp)
+			reg = (Registry *)img->getPointer(cp);
+		else
+			reg = NULL;
+		if(reg)
+			accept = reg->accept;
+		else
+			accept = 0;
+		if(accept < Driver::sip.accept_timer)
+			accept = Driver::sip.accept_timer;
+		if(!accept)
+		{
+			event->id = TIMER_EXPIRED;
+			return false;
+		}
+		startTimer(accept);
 		return true;
 	}
 
@@ -1150,6 +1210,12 @@ bool Session::enterReconnect(Event *event)
 
 	switch(event->id)
 	{
+	case RECALL_RECONNECT:
+		if(!encoding_recall)
+			return false;
+
+		event->reconnect.framing = framing_recall;
+		event->reconnect.encoding = encoding_recall;		
 	case ENTER_RECONNECT:
 		if(noinvite)
 			return false;
@@ -1164,6 +1230,9 @@ bool Session::enterReconnect(Event *event)
 		}
 
 		enc = event->reconnect.encoding;
+		if(!enc)
+			enc = audioEncoding();
+
 		if(*enc == '.')
 			++enc;
 		else if(!stricmp(enc, "mulaw"))
@@ -1219,6 +1288,7 @@ recon:
 		setEncoding(event->reconnect.encoding, event->reconnect.framing);
 		data_payload = sdpPayload();
 		state.timeout = 0;
+		encoding_recall = NULL;
 		return true;
 	case DIAL_FAILED:
 		memcpy(&info, &info_saved, sizeof(info));
@@ -1265,9 +1335,30 @@ bool Session::enterXfer(Event *event)
 	switch(event->id)
 	{
 	case DIAL_FAILED:
+		if(reconnecting)
+		{
+			noinvite = true;
+			goto refer;
+		}
 		event->id = DIAL_INVALID;
+	case DIAL_BUSY:
+	case DIAL_INVALID:
+	case ERROR_STATE:
+		reconnect();
 		return false;
 	case ENTER_STATE:
+		if(noinvite)
+			goto refer;
+		reconnecting = true;
+		redirect("0.0.0.0:0", sdpEncoding(), data_payload, dtmf_payload);		
+		startTimer(250);
+		return true;
+	case CALL_ANSWERED:
+		reconnecting = false;
+		stopTimer();
+	case TIMER_EXPIRED:
+refer:
+		reconnecting = false;
 		eXosip_lock();
 		eXosip_call_build_refer(did, (char *)state.url.ref, &refer);
 		rtn = eXosip_call_send_request(did, refer);
@@ -1281,6 +1372,9 @@ bool Session::enterXfer(Event *event)
 	case STOP_DISCONNECT:
 		setState(STATE_HANGUP);
 		return true;
+	case DTMF_KEYDOWN:
+	case DTMF_KEYUP:
+		return true;
 	default:
 		return false;
 	}	
@@ -1342,11 +1436,6 @@ timeout_t Session::audioFraming(void)
 	return info.framing;
 }
 
-const char *Session::audioEncoding(void)
-{
-	return Audio::getName(info.encoding);
-}
-
 const char *Session::checkAudio(bool live)
 {
 	audio.libext = ".au";
